import { ForbiddenException, Injectable } from '@nestjs/common';
import { Operador } from 'src/operador/entity/operador.entity';
import { Usuario } from 'src/usuario/entity/usuario.entity';

@Injectable()
export class ValidarUsuarioService {
  validarUsuario(usuario: Usuario) {
    if (!usuario) this.sinPermisos();
  }

  validarAdmin(admin: Operador) {
    if (!admin || admin.tipoUsuario.id_tipo_usuario != 3) this.sinPermisos();
  }

  validarAdminOperador(admin: Operador) {
    if (
      !admin ||
      (admin.tipoUsuario.id_tipo_usuario != 3 &&
        admin.tipoUsuario.id_tipo_usuario != 4)
    )
      this.sinPermisos();
  }

  validarOperador(operador: Operador) {
    if (
      !operador ||
      (operador.tipoUsuario.id_tipo_usuario != 2 &&
        operador.tipoUsuario.id_tipo_usuario != 3 &&
        operador.tipoUsuario.id_tipo_usuario != 4)
    )
      this.sinPermisos();
  }

  validarSuperAdmin(superAdmin: Operador) {
    if (!superAdmin || superAdmin.tipoUsuario.id_tipo_usuario != 2)
      this.sinPermisos();
  }

  validarSuperAdminAdmin(admin: Operador) {
    if (
      !admin ||
      (admin.tipoUsuario.id_tipo_usuario != 2 &&
        admin.tipoUsuario.id_tipo_usuario != 3)
    )
      this.sinPermisos();
  }

  sinPermisos() {
    throw new ForbiddenException(
      'No tienes los permisos necesarios para realizar esta acción.',
    );
  }
}
